%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print (get_python_lib(1))")}

%global _hardened_build 1

%global __provides_exclude_from ^%{python_sitearch}/fts/.*\\.so$

Name:       fts
Version:    3.5.7
Release:    1%{?dist}
Summary:    File Transfer Service V3
Group:      Applications/Internet
License:    ASL 2.0
URL:        https://svnweb.cern.ch/trac/fts3/wiki
# The source for this package was pulled from upstream's vcs.  Use the
# following commands to generate the tarball:
#  git clone https://gitlab.cern.ch/fts/fts3.git -b master --depth=1 fts-3.5.7
#  cd fts-3.5.7
#  cd ..
#  tar --exclude-vcs -vczf fts-3.5.7.tar.gz fts-3.5.7
Source0:   %{name}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%if %{?fedora}%{!?fedora:0} >= 21 || %{?rhel}%{!?rhel:0} >= 7
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  libcurl-devel
BuildRequires:  libuuid-devel
BuildRequires:  python2-devel
%else
BuildRequires:  boost148-devel
BuildRequires:  cmake28
BuildRequires:  curl-devel
BuildRequires:  e2fsprogs-devel
BuildRequires:  gcc44-c++
BuildRequires:  python-devel
%endif

BuildRequires:  CGSI-gSOAP-devel >= 1.3.6
BuildRequires:  doxygen
BuildRequires:  glib2-devel
BuildRequires:  globus-gsi-credential-devel
BuildRequires:  gridsite-devel
BuildRequires:  gsoap-devel
BuildRequires:  is-interface-devel
BuildRequires:  openldap-devel
Requires(pre):  shadow-utils

%description
File Transfer Service V3

%package client 
Summary:        File Transfer Service V3 Clients 
Group:          Applications/Internet

%description client
A set of command line tools for submitting, querying
and canceling transfer-jobs to the FTS service. Additionally,
there is a CLI that can be used for configuration and
administering purposes.

%package -n fts-libs
Summary: File Transfer Service version 3 libraries
Group: System Environment/Libraries

%description -n fts-libs
FTS common libraries used across the client and
server. This includes among others: configuration
parsing, logging and error-handling utilities, as
well as, common definitions and interfaces

%clean
rm -rf %{buildroot}

%prep
%setup -q

%build
# Make sure the version in the spec file and the version used
# for building matches
fts_cmake_ver=`sed -n 's/^set(VERSION_\(MAJOR\|MINOR\|PATCH\) \([0-9]\+\).*/\2/p' CMakeLists.txt | paste -sd '.'`
fts_spec_ver=`expr "%{version}" : '\([0-9]*\\.[0-9]*\\.[0-9]*\)'`
if [ "$fts_cmake_ver" != "$fts_spec_ver" ]; then
    echo "The version in the spec file does not match the CMakeLists.txt version!"
    echo "$fts_cmake_ver != %{version}"
    exit 1
fi

# Build
mkdir build
cd build
%if %{?fedora}%{!?fedora:0} >= 10 || %{?rhel}%{!?rhel:0} >= 6
    %cmake -DCLIENTBUILD=ON -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCMAKE_INSTALL_PREFIX='' \
    ..
%else
    %cmake28 -DCMAKE_C_COMPILER=/usr/bin/gcc44 -DCMAKE_CXX_COMPILER=/usr/bin/g++44 -DCLIENTBUILD=ON -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCMAKE_INSTALL_PREFIX='' \
    ..
%endif

make %{?_smp_mflags}

%install
cd build
make install DESTDIR=%{buildroot}

# Libs scriptlets
%post -n fts-libs -p /sbin/ldconfig

%postun -n fts-libs -p /sbin/ldconfig

%files client
%defattr(-,root,root,-)
%{_bindir}/fts-config-set
%{_bindir}/fts-config-get
%{_bindir}/fts-config-del
%{_bindir}/fts-set-debug
%{_bindir}/fts-set-blacklist
%{_bindir}/fts-set-priority
%{_bindir}/fts-transfer-list
%{_bindir}/fts-transfer-status
%{_bindir}/fts-transfer-submit
%{_bindir}/fts-transfer-delete
%{_bindir}/fts-transfer-cancel
%{_bindir}/fts-transfer-snapshot
%{_bindir}/fts-delegation-init

%{_mandir}/man1/fts*

%files -n fts-libs
%defattr(-,root,root,-)
%{_libdir}/libfts_common.so*
%{_libdir}/libfts_cli_common.so*
%{_libdir}/libfts_ws_ifce_client.so*
%{_libdir}/libfts_ws_ifce_server.so*
%{_libdir}/libfts_delegation_api_simple.so*
%{_libdir}/libfts_delegation_api_cpp.so*
%doc README.md
%doc LICENSE

%changelog
* Tue Nov 15 2016 Alejandro Alvarez <aalvarez@cern.ch> - 3.5.7-1
- New upstream release

* Mon Apr 18 2016 Alejandro Alvarez <aalvarez@cern.ch> - 3.4.3-1
- New upstream release

* Tue Sep 08 2015 Alejandro Alvarez <aalvarez@cern.ch> - 3.3.1-2
- Patch to disable Google Coredumper in non x86 architectures

* Fri Sep 04 2015 Alejandro Alvarez Ayllon <aalvarez@cern.ch> - 3.3.1-1
- Update for new upstream release

* Thu Mar 05 2015 Alejandro Alvarez Ayllon <aalvarez@cern.ch> - 3.2.32-1
  - Update for new upstream release
* Mon Dec 01 2014 Alejandro Alvarez Ayllon <aalvarez@cern.ch> - 3.2.30-2
  - Fixed bad dependency
* Thu Nov 27 2014 Alejandro Alvarez Ayllon <aalvarez@cern.ch> - 3.2.30-1
  - Update for new upstream release
  - CLI only for epel5
* Thu Sep 04 2014 Orion Poplawski <orion@cora.nwra.com> - 3.2.26.2-4
  - Rebuild for pugixml 1.4
* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.26.2-3
  - Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild
* Wed Aug 13 2014 Michal Simon <michal.simon@cern.ch> - 3.2.26.2-2
  - Update for new upstream releas
* Tue Feb 04 2014 Alejandro Alvarez <aalvarez@cern.ch> - 3.2.26-1
  - introduced dist back in the release
* Mon Jan 13 2014 Alejandro Alvarez <aalvarez@cern.ch> - 3.2.25-2
  - separated rpms for messaging and infosys subsystems
* Mon Nov 18 2013 Alejandro Alvarez Ayllon <aalvarez@cern.ch> - 3.1.33-2
  - Added missing changelog entry
  - Fixed bogus date
* Tue Oct 29 2013 Michal Simon <michal.simon@cern.ch> - 3.1.33-1
  - Update for new upstream release
* Wed Aug 07 2013 Michal Simon <michal.simon@cern.ch> - 3.1.1-2
  - no longer linking explicitly to boost libraries with '-mt' sufix 
* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.0-3
  - Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild
* Sat Jul 27 2013 Petr Machata <pmachata@redhat.com> - 3.1.0-2
  - rebuild for boost 1.54.0
  - boost package doesn't use tagged sonames anymore, drop the -mt
    suffix from several boost libraries (fts-3.1.0-boost_mt.patch)
* Wed Jul 24 2013 Michal Simon <michal.simon@cern.ch> - 3.0.3-15
  - compatible with rawhide (f20)
* Tue Jul 02 2013 Michail Salichos <michail.salichos@cern.ch> - 3.0.3-14
  - mysql queries optimization
* Fri Jun 14 2013 Michal Simon <michal.simon@cern.ch> - 3.0.3-1
  - dependency on 'gfal2-plugin-http' has been removed
  - the calls to mktemp have been removed
  - cmake build type changed from Release to RelWithDebInfo
  - EPEL5 specifics have been removed from spec files
  - changelog has been fixed
* Fri May 24 2013 Michal Simon <michal.simon@cern.ch> - 3.0.2-1
  - speling has been fixed in package's description
  - man pages added to devel package
  - services are disabled by default
  - missing 'Requires(post): chkconfig' and 'Requires(preun): chkconfig' added
* Tue Apr 30 2013 Michal Simon <michal.simon@cern.ch> - 3.0.1-1
  - BuildRequires and Requires entries have been sorted alphabetically
  - the non standard compilation options have been removed
  - package and the subpackages descriptions have been updated
  - documentation files listed as %doc
  - trailing white-spaces have been removed
* Wed Apr 24 2013 Michal Simon <michal.simon@cern.ch> - 3.0.0-1
  - First EPEL release

